@@ -4,5 +4,6 @@ from .mongo_writer import MongoWriter
 from .mysql_writer import MySqlWriter
 from .txt_writer import TxtWriter
 from .sqlite_writer import SqliteWriter
+from .kafka_writer import KafkaWriter
 
-__all__ = [CsvWriter, TxtWriter, JsonWriter, MongoWriter, MySqlWriter, SqliteWriter]
+__all__ = [CsvWriter, TxtWriter, JsonWriter, MongoWriter, MySqlWriter, SqliteWriter, KafkaWriter]
